@@ -3,14 +3,14 @@ use mimeograph_router::*;
 type Result<T> = std::result::Result<T, Box<dyn std::error::Error>>;
 
 #[get("/foo/bar/baz")]
-pub fn foo_bar_baz(_request: &http::Request<String>) -> Result<http::Response<String>> {
+pub fn foo_bar_baz(_request: http::Request<String>) -> Result<http::Response<String>> {
     http::Response::builder()
         .body(String::from("hello world"))
         .map_err(Into::into)
 }
 
 #[get("/bar/baz/:qux")]
-pub fn bar_baz_qux(_request: &http::Request<String>, qux: &str) -> Result<http::Response<String>> {
+pub fn bar_baz_qux(_request: http::Request<String>, qux: &str) -> Result<http::Response<String>> {
     http::Response::builder()
         .body(qux.to_owned())
         .map_err(Into::into)
@@ -25,7 +25,7 @@ fn match_get() {
     // match the second route
     let router = router![bar_baz_qux, foo_bar_baz];
 
-    let response = router(&request);
+    let response = router(request);
 
     // should be Some(Ok(..))
     let body = response.expect("matched").unwrap().into_body();
@@ -40,7 +40,7 @@ fn match_get_with_arg() {
 
     let router = router![bar_baz_qux, foo_bar_baz];
 
-    let response = router(&request);
+    let response = router(request);
 
     // should be Some(Ok(..))
     let body = response.expect("matched").unwrap().into_body();
